CHANGELOG
=========

v0.0.10
-------
05/12/2020

 * perf: Sending in signals query params

v0.0.9
-------
05/11/2020

 * perf: Add signal registration user

v0.0.8
-------
05/11/2020

 * fix: Include HTML and static files

v0.0.7
-------
05/11/2020

 * feat: Add recovery password

v0.0.6
-------
04/23/2020

 * fix: Possible hardcoded secret key (secret)
 * fix: PEP 257 in converters.py
 * style: Great code optimization done (see https://app.codacy.com/manual/kostya/django_simple_account/)

v0.0.5
-------
04/22/2020

 * Beta version

v0.0.4
-------
04/22/2019

 * Avatar preview added to admin panel
 * Big avatars are now downloading 512x512 size
 * Application renamed in Django admin panel

v0.0.3
-------
04/22/2020

 * Delete google-api-python-client library (is deprecated)
 * Minor documentation changes
 * Bump version
